@@ -1,7 +1,7 @@
 /*****************************************************************************\
   Encapsulator.cpp : Encapsulator class implementation
 
-  Copyright (c) 1996 - 2001, Hewlett-Packard Co.
+  Copyright (c) 1996 - 2015, HP Co.
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -12,7 +12,7 @@
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
-  3. Neither the name of Hewlett-Packard nor the names of its
+  3. Neither the name of HP nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.
 
@@ -65,7 +65,7 @@ DRIVER_ERROR Encapsulator::StartJob(SystemServices *pSystemServices, JobAttribut
     memset(pcl_buffer, 0, cur_pcl_buffer_size);
     cur_pcl_buffer_ptr = pcl_buffer;
 
-    err = flushPrinterBuffer();
+    err = NO_ERROR;
 
     struct    tm    *t;
     time_t    long_time;
@@ -77,6 +77,8 @@ DRIVER_ERROR Encapsulator::StartJob(SystemServices *pSystemServices, JobAttribut
 
 //  Now add other header info
 
+
+#ifndef UNITTESTING
     if (jobAttrPJLAllowed())
     {
         addToHeader("@PJL SET STRINGCODESET=UTF8\012");
@@ -104,6 +106,7 @@ DRIVER_ERROR Encapsulator::StartJob(SystemServices *pSystemServices, JobAttribut
 
         addToHeader("@PJL SET USERNAME=\"%s\"\012", m_pJA->user_name);
     }
+#endif
 
 //  Add platform specific PJL here
     addJobSettings();
